@@ -217,7 +217,7 @@ class PostEndpoints:
         # Update the request body with update fields
         base_body.update(fields_to_update)
 
-        response = self.base_class.post_data(uri='PositionPost/*', data=base_body, return_key='OrgUnitID')
+        response = self.base_class.post_data(uri='PositionPost/*', data=base_body, return_key='PositionID')
         return response
 
     def post_workcenter(self, data: dict, overload_fields: dict = None):
@@ -245,6 +245,6 @@ class PostEndpoints:
         # Update the request body with update fields
         base_body.update(fields_to_update)
 
-        response = self.base_class.post_data(uri='WorkcenterPost/*', data=data, return_key='WorkcenterID')
+        response = self.base_class.post_data(uri='WorkcenterPost/*', data=data, return_key=None)
         return response
 
